@@ -3,7 +3,7 @@
 find_distance_to_pca_means <- function(pcs, pca_means) {
   diffs <- sweep(pcs, 2, pca_means)
   sq_diff <- diffs^2
-  dists <- apply(sq_diff, 1, function(x) sqrt(sum(x)))
+  dists <- apply(sq_diff, 1, \(x) sqrt(sum(x)))
   dists
 }
 
